<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Settings extends Controller {

    function __construct() {
            parent::Controller();
            $module_name = "config";
            $this->load->model($this->config->item('smp_model'));
    }

    //---------------------------------------------------------------

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE SETTINGS LIST PAGE">
    /*
     * Function: index
     * Description: Shows the settings list page
     * ##############################################################
     * Written: 10/22/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function index($offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'settings/record',
            'View All'    =>  'settings'
        );
        smp_set_page_meta('config', 'settings', $page_button_set);
        //</editor-fold>

        //<editor-fold desc="CREATE SEARCH FORM">
        $search_form_fields = array(
            array(
                'field'    =>  'key_title',
                'label'    =>  'Title',
                'type'     =>  'text',
                'class'    =>  '',
                'value'    =>  ''
            )
        );
        smp_create_form($search_form_fields, $this->config->item('form_setting_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="FETCHING DATA">
        $where_additional = smp_form_where_clause($_POST, $this->config->item('tbl_config'));
        if (!$where_additional){
            $where_additional = '(key_type = \'USER\' OR key_type = \'CUSTOM\' ) AND flg_enabled = \'Y\'';
        }
        else{
            $where_additional = 'AND ((key_type = \'USER\' OR key_type = \'CUSTOM\') AND flg_enabled = \'Y\')';
        }

        $total_records = smp_count($this->config->item('tbl_config'), $where_additional);
        $result_set['settings'] = $this->Smp_model->get_records($this->config->item('tbl_config'), $where_additional, $offset, $this->config->item('records_per_page'));
        $pagination = smp_set_pagination($this->config->item('page_list_settings'), $total_records);
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->set('resultset', $result_set['settings']);
        $this->template->set('pagination', $pagination);
        $this->template->view($this->config->item('setting_list_view'));
        //</editor-fold>
    }

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE SETTING VIEW/EDIT PAGE">
    /**
     * Function: record
     * Description: Shows the setting view/edit page
     * ##############################################################
     * Written: 10/22/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function record($key_id = '', $offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'settings/record',
            'View All'    =>  'settings'
        );
        smp_set_page_meta('config', 'settings', $page_button_set);
        //</editor-fold>

        //<editor-fold desc="FETCH FORM RULES & EXECUTE">
        $rules_config = smp_get_rules('settings');
        $this->form_validation->set_rules($rules_config);
        //</editor-fold>

        //<editor-fold desc="CREATE SEARCH FORM">
        $search_form_fields = array(
            array(
                'field'    =>  'title',
                'label'    =>  'Title',
                'type'     =>  'text',
                'class'    =>  '',
                'value'    =>  ''
            )
        );
        smp_create_form($search_form_fields, $this->config->item('form_setting_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="POPULATE THE FORM">
        if ($key_id): $where_additional = "key_id = " . $key_id; else: $where_additional = "key_id = 0"; endif;

        if ($this->input->post('action') && $this->form_validation->run()){
            smp_process_form($_POST, $this->config->item('tbl_config'), 'key_id = ' . $key_id, 'config/settings');
        }
        $result_set = $this->Smp_model->get_records($this->config->item('tbl_config'), $where_additional, $offset, $this->config->item('records_per_page'));

        if ($result_set):
            foreach ($result_set as $value){
                /*  Create edit form */
                $setting_form_fields = array(
                   array(
                         'field'    =>  'key_id',
                         'label'    =>  'Key ID',
                         'type'     =>  'hidden',
                         'class'    =>  'small',
                         'value'    =>  $value->key_id
                      ),
                   array(
                         'field'    =>  'key_name',
                         'label'    =>  'Setting Key',
                         'type'     =>  'hidden',
                         'class'    =>  'small',
                         'value'    =>  $value->key_name
                      ),
                   array(
                         'field'    =>  'key_name',
                         'label'    =>  'Setting Key',
                         'type'     =>  'label',
                         'class'    =>  'medium',
                         'value'    =>  $value->key_name
                      ),
                   array(
                         'field'    =>  'key_title',
                         'label'    =>  'Setting Title',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->key_title
                      ),
                    array(
                         'field'    =>  'key_value',
                         'label'    =>  'Setting Value',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->key_value
                      ),
                    array(
                         'field'    =>  'key_help',
                         'label'    =>  'Description',
                         'type'     =>  'textarea',
                         'class'    =>  'small',
                         'value'    =>  $value->key_help
                      )
                );
                if ($value->key_type == 'CUSTOM'){
                    smp_create_form($setting_form_fields, $this->config->item('form_setting_record') . '/' . $key_id, 'form_record', 'perm_delete');
                }
                else if ($value->key_type == 'USER'){
                    smp_create_form($setting_form_fields, $this->config->item('form_setting_record') . '/' . $key_id, 'form_record', 'perm_save');
                }
            }
        else:
            /*  Create view form */
                $setting_form_fields = array(
                   array(
                         'field'    =>  'key_name',
                         'label'    =>  'Setting Key',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  ''
                      ),
                   array(
                         'field'    =>  'key_title',
                         'label'    =>  'Setting Title',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  ''
                      ),
                    array(
                         'field'    =>  'key_value',
                         'label'    =>  'Setting Value',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  ''
                      ),
                    array(
                         'field'    =>  'key_help',
                         'label'    =>  'Description',
                         'type'     =>  'textarea',
                         'class'    =>  'small',
                         'value'    =>  ''
                      ),
                    array(
                         'field'    =>  'key_type',
                         'label'    =>  'Key Type',
                         'type'     =>  'hidden',
                         'class'    =>  'small',
                         'value'    =>  'CUSTOM'
                      ),
                    array(
                         'field'    =>  'flg_enabled',
                         'label'    =>  'Flag',
                         'type'     =>  'hidden',
                         'class'    =>  'small',
                         'value'    =>  'Y'
                      )
                );
                smp_create_form($setting_form_fields, $this->config->item('form_setting_record'), 'form_record', 'perm_add', 'plain');
        endif;
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->view($this->config->item('record_view'));
        //</editor-fold>
    }

     /**
     * Function: delete
     * Description: Deletes the Record
     * ##############################################################
     * Written: 05/01/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function delete($template_id = '')
    {
        //<editor-fold desc="DELETE RECORD">
        if (smp_check_permission($this->config->item('perm_delete'))){
            $this->Shop_model->process_product('', 'Delete', 'product_id = ' . $product_id, 'shop/products');
        }
        //</editor-fold>
    }


}

/* End of file settings.php */
/* Location: ./app/controllers/config/settings.php */