<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Orders extends Controller {

    function __construct() {
            parent::Controller();
            $module_name = "shop";
            //$this->template->set('system_message', '');
            $this->load->model($this->config->item('shop_model'));
            $this->load->model($this->config->item('smp_model'));
            $this->lang->load('shop', 'english');
    }

    //---------------------------------------------------------------

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE ORDERS LIST PAGE">
    /*
     * Function: index
     * Description: Shows the orders list page
     * ##############################################################
     * Written: 05/16/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function index($offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'orders/record',
            'View All'    =>  'orders'
        );
        smp_set_page_meta('shop', 'order', $page_button_set);
        //</editor-fold>
        
        //<editor-fold desc="CREATE SEARCH FORM">
        $search_form_fields = array(
            array(
                'field'    =>  'gateway_id',
                'label'    =>  'Transaction ID',
                'type'     =>  'text',
                'class'    =>  'small',
                'value'    =>  ''
            ),
            /*array(
                'field'    =>  'product_id',
                'label'    =>  'Product',
                'type'     =>  'dropdown',
                'class'    =>  'large',
                'value'    =>  get_options($this->config->item('tbl_products'), 'product_id', 'product_name', ''),
                'selected' =>  ''
            ),*/
            array(
                'field'    =>  'user',
                'label'    =>  'Username OR Email',
                'type'     =>  'text',
                'class'    =>  'small',
                'value'    =>  ''
            ),
            array(
                'field'    =>  'transaction_status_details',
                'label'    =>  'Order Status',
                'type'     =>  'dropdown',
                'class'    =>  '',
                'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name = \'TRANS_STATUS\''),
                'selected' =>  ''
            )
        );
        smp_create_form($search_form_fields, $this->config->item('form_order_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="FETCHING DATA">
        if (isset($_POST['user'])){
            $_POST['user_id'] = smp_lookup('user_id', $this->config->item('tbl_users'), 'username = \'' . $_POST['user'] . '\' OR email = \'' . $_POST['user'] . '\'');
            unset($_POST['user']);
        }
        $where_additional = smp_form_where_clause($_POST, $this->config->item('tbl_transactions'));
        $total_records = smp_count($this->config->item('tbl_transactions'), $where_additional);
        $result_set['orders'] = $this->Shop_model->get_orders($offset, $this->config->item('records_per_page'), $where_additional);
        $pagination = smp_set_pagination($this->config->item('page_list_orders'), $total_records);
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->set('resultset', $result_set['orders']);
        $this->template->set('pagination', $pagination);
        $this->template->view($this->config->item('order_list_view'));
        //</editor-fold>
    }

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE ORDER VIEW/EDIT PAGE">
    /**
     * Function: record
     * Description: Shows the order view/edit page
     * ##############################################################
     * Written: 05/16/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function record($transaction_id = '', $offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'orders/record',
            'View All'    =>  'orders'
        );
        smp_set_page_meta('shop', 'order', $page_button_set);
        //</editor-fold>

        //<editor-fold desc="FETCH FORM RULES & EXECUTE">
        $rules_config = smp_get_rules('orders');
        $this->form_validation->set_rules($rules_config);
        //</editor-fold>

        //<editor-fold desc="CREATE SEARCH FORM">
                $search_form_fields = array(
            array(
                'field'    =>  'gateway_id',
                'label'    =>  'Transaction ID',
                'type'     =>  'text',
                'class'    =>  'small',
                'value'    =>  ''
            ),
            /*array(
                'field'    =>  'product_id',
                'label'    =>  'Product',
                'type'     =>  'dropdown',
                'class'    =>  'large',
                'value'    =>  get_options($this->config->item('tbl_products'), 'product_id', 'product_name', ''),
                'selected' =>  ''
            ),*/
            array(
                'field'    =>  'user',
                'label'    =>  'Username OR Email',
                'type'     =>  'text',
                'class'    =>  'small',
                'value'    =>  ''
            ),
            array(
                'field'    =>  'transaction_status_details',
                'label'    =>  'Order Status',
                'type'     =>  'dropdown',
                'class'    =>  '',
                'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name = \'TRANS_STATUS\''),
                'selected' =>  ''
            )
        );
        smp_create_form($search_form_fields, $this->config->item('form_order_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="POPULATE THE FORM">
        if ($transaction_id): $where_additional = "transaction_id = " . $transaction_id; else: $where_additional = "transaction_id = 0"; endif;

        if ($this->input->post('action') && $this->form_validation->run()){
            //smp_process_form($_POST, $this->config->item('tbl_transactions'), 'transaction_id = ' . $transaction_id, 'shop/orders');
            if (smp_action_permission($this->input->post('action'))) {
                $this->Shop_model->process_order($_POST, $this->input->post('action'), 'transaction_id = ' . $transaction_id, 'shop/orders');
            }
        }
        $result_set = $this->Smp_model->get_records($this->config->item('tbl_transactions'), $where_additional, $offset, $this->config->item('records_per_page'));

        if ($result_set):
            $product_purchased = smp_lookup('product_id', $this->config->item('tbl_order_items'), 'order_id = ' . $transaction_id);
            foreach ($result_set as $value){
                
                /* Authorize.net code implementation
                if($value->next_bill_date){
                    switch($value->next_billed_flg){
                        case "N":
                            $subscription_status = "ACTIVE";
                        break;
                        case "F":
                            $subscription_status = "ACTIVE";
                        break;
                        case "C":
                            $subscription_status = "CANCELLED";
                        break;

                        default:
                        break;
                    }
                }
                */

                /*  Create edit form */
                $order_form_fields = array(
                   array(
                         'field'    =>  'user',
                         'label'    =>  'User/Email',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  smp_lookup('username', $this->config->item('tbl_users'), 'user_id = ' . $value->user_id),
                         'help'     =>  $this->lang->line('f_orders_user')
                   ),
                    array(
                         'field'    =>  'product_id',
                         'label'    =>  'Product',
                         'type'     =>  'dropdown',
                         'class'    =>  'medium',
                         'value'    =>  get_options($this->config->item('tbl_products'), 'product_id', 'product_name', ''),
                         'selected' =>  $product_purchased
                      ),
                   array(
                         'field'    =>  'transaction_date',
                         'label'    =>  'Order Date',
                         'type'     =>  'date',
                         'class'    =>  'small',
                         'value'    =>  $value->transaction_date
                      ),
                    array(
                         'field'    =>  'transaction_amount',
                         'label'    =>  'Amount',
                         'type'     =>  'text',
                         'class'    =>  'small',
                         'value'    =>  $value->transaction_amount,
                         'help'     =>  $this->lang->line('f_orders_amount')
                      ),
                    array(
                         'field'    =>  'channel',
                         'label'    =>  'Payment Processor',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_gateways'), 'title', 'title', ''),
                         'selected' =>  $value->channel,
                         'help'     =>  $this->lang->line('f_orders_channel')
                      ),
                    array(
                         'field'    =>  'gateway_id',
                         'label'    =>  'Transaction ID',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  $value->gateway_id
                      ),
                    array(
                         'field'    =>  'transaction_status_details',
                         'label'    =>  'Order Status',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name = \'TRANS_STATUS\''),
                         'selected' =>  $value->transaction_status_details
                      ),
                    array(
                         'field'    =>  'begin_date',
                         'label'    =>  'Begin Date',
                         'type'     =>  'date',
                         'class'    =>  'small',
                         'value'    =>  $value->begin_date
                      ),
                    array(
                         'field'    =>  'expire_date',
                         'label'    =>  'Expire Date',
                         'type'     =>  'date',
                         'class'    =>  'small',
                         'value'    =>  $value->expire_date
                      ),
                    array(
                         'field'    =>  'notify_customer',
                         'label'    =>  'Notify Customer',
                         'type'     =>  'checkbox',
                         'class'    =>  '',
                         'value'    =>  '',
                         'help'     =>  $this->lang->line('f_notify_customer')
                      ),
                    array(
                         'field'    =>  'transaction_notes',
                         'label'    =>  'Notes',
                         'type'     =>  'textarea',
                         'class'    =>  'small',
                         'value'    =>  $value->transaction_notes
                      ),
                    array(
                         'field'    =>  'transaction_id',
                         'label'    =>  'Order ID',
                         'type'     =>  'hidden',
                         'class'    =>  'small',
                         'value'    =>  $transaction_id
                      )
                );
                
                smp_create_form($order_form_fields, $this->config->item('form_order_record') . '/' . $transaction_id, 'form_record', 'perm_delete');
            }
        else:
            /*  Create view form */
                $order_form_fields = array(
                    array(
                         'field'    =>  'user',
                         'label'    =>  'User/Email',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  '',
                         'help'     =>  $this->lang->line('f_orders_user')
                      ),
                    array(
                         'field'    =>  'product_id',
                         'label'    =>  'Product',
                         'type'     =>  'dropdown',
                         'class'    =>  'medium',
                         'value'    =>  get_options($this->config->item('tbl_products'), 'product_id', 'product_name', ''),
                         'selected' =>  ''
                      ),
                   array(
                         'field'    =>  'transaction_date',
                         'label'    =>  'Order Date',
                         'type'     =>  'date',
                         'class'    =>  'small',
                         'value'    =>  ''
                      ),
                    array(
                         'field'    =>  'transaction_amount',
                         'label'    =>  'Amount',
                         'type'     =>  'text',
                         'class'    =>  'small',
                         'value'    =>  '',
                         'help'     =>  $this->lang->line('f_orders_amount')
                      ),
                    array(
                         'field'    =>  'channel',
                         'label'    =>  'Payment Processor',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_gateways'), 'title', 'title', ''),
                         'selected' =>  '',
                         'help'     =>  $this->lang->line('f_orders_channel')
                      ),
                    array(
                         'field'    =>  'gateway_id',
                         'label'    =>  'Transaction ID',
                         'type'     =>  'text',
                         'class'    =>  'medium',
                         'value'    =>  ''
                      ),
                    array(
                         'field'    =>  'transaction_status_details',
                         'label'    =>  'Order Status',
                         'type'     =>  'dropdown',
                         'class'    =>  'small',
                         'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name = \'TRANS_STATUS\''),
                         'selected' =>  ''
                      ),
                    array(
                         'field'    =>  'begin_date',
                         'label'    =>  'Begin Date',
                         'type'     =>  'date',
                         'class'    =>  'small',
                         'value'    =>  ''
                      ),
                    array(
                         'field'    =>  'expire_date',
                         'label'    =>  'Expire Date',
                         'type'     =>  'date',
                         'class'    =>  'small',
                         'value'    =>  ''
                      ),
                    array(
                         'field'    =>  'notify_customer',
                         'label'    =>  'Notify Customer',
                         'type'     =>  'checkbox',
                         'class'    =>  '',
                         'value'    =>  '',
                         'help'     =>  $this->lang->line('f_notify_customer')
                      ),
                    array(
                         'field'    =>  'transaction_notes',
                         'label'    =>  'Notes',
                         'type'     =>  'textarea',
                         'class'    =>  'small',
                         'value'    =>  ''
                      )
                );
            smp_create_form($order_form_fields, $this->config->item('form_order_record'), 'form_record', 'perm_add', 'plain');

        endif;
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->view($this->config->item('record_view'));
        //</editor-fold>
    }

    //<editor-fold desc="FUNCTION DESCRIPTION: SHOW THE USERS ORDERS LIST PAGE">
    /*
     * Function: history
     * Description: Shows the user orders list page
     * ##############################################################
     * Written: 05/16/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    //</editor-fold>
    function history($user_id = 0, $offset = '')
    {
        //<editor-fold desc="CHECK USER PERMISSION">
        smp_check_permission($this->config->item('perm_view'));
        //</editor-fold>

        //<editor-fold desc="SET PAGE META">
        $page_button_set = array(
            'Add New'    =>  'orders/record',
            'View All'    =>  'orders'
        );
        smp_set_page_meta('shop', 'order', $page_button_set);
        //</editor-fold>

        //<editor-fold desc="CREATE SEARCH FORM">
        $search_form_fields = array(
            array(
                'field'    =>  'gateway_id',
                'label'    =>  'Transaction ID',
                'type'     =>  'text',
                'class'    =>  'small',
                'value'    =>  ''
            ),
            /*array(
                'field'    =>  'product_id',
                'label'    =>  'Product',
                'type'     =>  'dropdown',
                'class'    =>  'large',
                'value'    =>  get_options($this->config->item('tbl_products'), 'product_id', 'product_name', ''),
                'selected' =>  ''
            ),*/
            array(
                'field'    =>  'user',
                'label'    =>  'Username OR Email',
                'type'     =>  'text',
                'class'    =>  'small',
                'value'    =>  ''
            ),
            array(
                'field'    =>  'transaction_status_details',
                'label'    =>  'Order Status',
                'type'     =>  'dropdown',
                'class'    =>  '',
                'value'    =>  get_options($this->config->item('tbl_config'), 'key_value', 'key_value', 'key_name = \'TRANS_STATUS\''),
                'selected' =>  ''
            )
        );
        smp_create_form($search_form_fields, $this->config->item('form_order_search'), 'form_search');
        //</editor-fold>

        //<editor-fold desc="FETCHING DATA">
        $where_additional = 'user_id = ' . $user_id;
        $total_records = smp_count($this->config->item('tbl_transactions'), $where_additional);
        $result_set['orders'] = $this->Shop_model->get_orders($offset, $this->config->item('records_per_page'), $where_additional);
        $pagination = smp_set_pagination($this->config->item('page_list_orderhistory') . "/" . $user_id, $total_records, 5);
        //</editor-fold>

        //<editor-fold desc="LOAD THE TEMPLATE">
        $this->template->set('resultset', $result_set['orders']);
        $this->template->set('pagination', $pagination);
        $this->template->view($this->config->item('order_list_view'));
        //</editor-fold>
    }

     /**
     * Function: delete
     * Description: Deletes the record
     * ##############################################################
     * Written: 05/01/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function delete($transaction_id = '')
    {
        //<editor-fold desc="DELETE RECORD">
        //smp_process_data("", "shop_products", "product_id = " . $product_id, "shop/products", "Delete");
        if (smp_check_permission($this->config->item('perm_delete'))){
            $field_array['transaction_id'] = $transaction_id;
            $this->Shop_model->process_order($field_array, 'Delete', '', 'shop/orders');
        }
        //</editor-fold>
    }

    function verify_user($str)
    {
        $this->load->model($this->config->item('user_model'));
        $user_id = $this->User_model->verify_user($str);
        if ($user_id)
        {
            $_POST['user_id'] = $user_id;
        }
        else
        {
            $this->form_validation->set_message('verify_user', $this->lang->line('message_invalid_user'));
            return FALSE;
        }
    }

}

/* End of file orders.php */
/* Location: ./app/controllers/shop/orders.php */